import { IBlockable, IDeletable, IExpirable, IIdentityProfile, IVertex } from '@e2/mongodb';
import { IAuditable } from '@e2/mongodb/lib/graph/IAuditable';
export interface IExternalUserIdentity {
    type: string;
    key?: string;
    value: string;
}
export interface IExternalUserKeyFields {
    uid: number | string;
    provider: string;
    providerProtocol: string | 'oauth' | 'oauth2' | 'bot';
}
export interface IExternalUserMandatoryFields extends IExternalUserKeyFields {
    uid: number | string;
    provider: string;
    providerProtocol: string | 'oauth' | 'oauth2' | 'bot';
    providerData: any;
    identities: Array<IExternalUserIdentity>;
}
export interface IExternalUserOptionalFields {
    username: string | null;
    domain: string | null;
    email: string | null;
    emailCertified: boolean;
    mobile: string | null;
    mobileCertified: boolean;
    displayName: string;
    displayImageURL: string | null;
    familyName: string | null;
    givenName: string | null;
    gender: string | null;
    dob: Date | null;
    status: string | null;
    bio: string | null;
    homepage: string | null;
}
export interface IExternalUser extends IVertex, IExternalUserMandatoryFields, IExternalUserOptionalFields, IExpirable, IAuditable, IBlockable, IDeletable {
    uid: number | string;
    provider: string;
    providerProtocol: string | 'oauth' | 'oauth2' | 'bot';
    providerData: any;
    identities: Array<IExternalUserIdentity>;
    username: string | null;
    domain: string | null;
    email: string | null;
    emailCertified: boolean;
    mobile: string | null;
    mobileCertified: boolean;
    displayName: string;
    displayImageURL: string | null;
    familyName: string | null;
    givenName: string | null;
    gender: string | null;
    dob: Date | null;
    status: string | null;
    bio: string | null;
    homepage: string | null;
    expires: Date;
    createdAt: Date;
    createdFrom: string;
    createdBy: IIdentityProfile;
    updatedAt: Date;
    updatedFrom: string;
    updatedBy: IIdentityProfile;
    blocked: boolean;
    blockedAt: Date;
    blockedFrom: string;
    blockedBy: IIdentityProfile;
    blockedReason: string;
    deleted: boolean;
    deletedAt: Date;
    deletedFrom: string;
    deletedBy: IIdentityProfile;
    deletedReason: string;
}
